package java.util;

import sun.util.ResourceBundleEnumeration;

public abstract class ListResourceBundle extends ResourceBundle
{
    private Map<String, Object> lookup;
    
    public ListResourceBundle() {
        this.lookup = null;
    }
    
    public final Object handleGetObject(String s) {
        if (this.lookup == null) {
            this.loadLookup();
        }
        if (s == null) {
            throw new NullPointerException();
        }
        return this.lookup.get(s);
    }
    
    @Override
    public Enumeration<String> getKeys() {
        if (this.lookup == null) {
            this.loadLookup();
        }
        ResourceBundle parent = this.parent;
        return new ResourceBundleEnumeration(this.lookup.keySet(), (parent != null) ? parent.getKeys() : null);
    }
    
    @Override
    protected Set<String> handleKeySet() {
        if (this.lookup == null) {
            this.loadLookup();
        }
        return this.lookup.keySet();
    }
    
    protected abstract Object[][] getContents();
    
    private synchronized void loadLookup() {
        if (this.lookup != null) {
            return;
        }
        Object[][] contents = this.getContents();
        HashMap<String, Object> lookup = new HashMap(contents.length);
        int i = 0;
        while (i < contents.length) {
            String s = (String)contents[i][0];
            Object o = contents[i][1];
            if (s == null || o == null) {
                throw new NullPointerException();
            }
            lookup.put(s, o);
            ++i;
        }
        this.lookup = lookup;
        return;
    }
}
